@@ -1,4 +1,4 @@
-static int SLang_pop_scomplex (complex *c)
+static int SLang_pop_scomplex (spcomplex *c)
 {
    double dc[2];
    if (SLang_pop_complex(dc, dc+1) == -1)
